@@ -6,16 +6,17 @@ Tools for analyzing UEFI firmware using radare2
 
 __author__ = "yeggor"
 __email__ = "yegor@binarly.io"
-__version__ = "1.2.0"
+__version__ = "1.2.1"
 
 from .uefi_analyzer import UefiAnalyzer, UefiAnalyzerError
-from .uefi_scanner import UefiRule, UefiScanner
+from .uefi_scanner import UefiRule, UefiScanner, UefiMultiScanner
 from .uefi_te import TerseExecutableParser
 
 __all__ = [
     "UefiAnalyzer",
     "UefiRule",
     "UefiScanner",
+    "UefiMultiScanner",
     "TerseExecutableParser",
     "UefiAnalyzerError",
 ]
